pub struct NotificationPrefs {
pub on_completion: bool,
pub on_failure: bool,
}Expand description
Per-event desktop-notification toggles. Surfaced in the Config
tab and held on the App for the current session only. They are
not part of the persisted Config, so they reset to off on each
restart.
Fields
on_completion: boolon_failure: boolTrait Implementations
Sourceimpl Clone for NotificationPrefs
impl Clone for NotificationPrefs
Sourcefn clone(&self) -> NotificationPrefs
fn clone(&self) -> NotificationPrefs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NotificationPrefs
impl Debug for NotificationPrefs
Sourceimpl Default for NotificationPrefs
impl Default for NotificationPrefs
Sourcefn default() -> NotificationPrefs
fn default() -> NotificationPrefs
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for NotificationPrefs
impl PartialEq for NotificationPrefs
Sourcefn eq(&self, other: &NotificationPrefs) -> bool
fn eq(&self, other: &NotificationPrefs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for NotificationPrefs
impl Eq for NotificationPrefs
impl StructuralPartialEq for NotificationPrefs