run_loops

Function run_loops 

pub async fn run_loops(
    cfg: SharedConfig,
    stop: Arc<AtomicBool>,
    logs: Arc<Mutex<Vec<LogEntry>>>,
    busy: Arc<AtomicBool>,
    observers: WorkerObservers,
    schedule: LoopSchedule,
)
Spawn the four loops with the supplied schedule and wait for them to exit. Pulled out of run so tests can drive the loop wrappers with short intervals.